from __future__ import annotations
__all__: list[str] = ['PMInterface', 'PMMember']
class PMInterface:
    def ClearNotUsed_GridJoint(self) -> int:
        ...
    def DeleteMember(self, arg0: list[PMMember]) -> int:
        ...
    def DrawDelete(self, arg0: list[PMMember]) -> int:
        ...
    def DrawSelect(self, arg0: list[PMMember]) -> int:
        ...
    def DrawUnSelect(self, arg0: list[PMMember]) -> int:
        ...
    def GetCurrentSelectSetMembers(self) -> list[PMMember]:
        ...
    def GetJWSPath(self) -> str:
        ...
    def QuitCurrentCommand(self) -> None:
        ...
    def ReDrawWholeModel(self) -> int:
        ...
    def SendCMD(self, arg0: str) -> bool:
        ...
    def SetSelectSet(self, arg0: list[PMMember]) -> int:
        ...
    def Undo_CLEAR(self) -> None:
        ...
    def Undo_INIT(self) -> None:
        ...
    def Undo_STEP(self) -> None:
        ...
    def __init__(self) -> None:
        ...
    def testMethod(self) -> str:
        ...
class PMMember:
    Kind: int
    NatureFloor: int
    PmID: int
    StandFloor: int
    def __init__(self) -> None:
        ...



from setuptools import setup
from setuptools.dist import Distribution

class BinaryDistribution(Distribution):
    def has_ext_modules(self):
        return True

setup(
    distclass=BinaryDistribution
)



from __future__ import annotations
import typing
__all__ = ['Bardata', 'Beam', 'BeamDesignData', 'BeamSection', 'BearingShear', 'Brace', 'BraceDesignData', 'BraceSection', 'Column', 'ColumnDesignData', 'ColumnSection', 'ConcreteGrade', 'EarthquakeNormStatData', 'ExceedLimitInfomation', 'LoadCaseData', 'LoadDefineData', 'MaterialData', 'ModePeriodData', 'Model', 'Net', 'Node', 'NodeDisp', 'NodeInResult', 'NormalDispStatData', 'Plao', 'PlaoSection', 'PlateLoadData', 'ProjectPara', 'PySectionProperty', 'RealFloor', 'ReinforcingbarGrade', 'ResultData', 'SectionKind', 'SectionShape', 'Slab', 'SlabHole', 'SlabHoleSection', 'SpecialBeam', 'SpecialBrace', 'SpecialColumn', 'SpecialWall', 'StandFloor', 'SteelGrade', 'StiffWeightRatioFrameData', 'StiffWeightRatioNonFrameData', 'StoreyStifData', 'StoreyStiffRatioData', 'StoreyUnitMassData', 'SysInfoDetail', 'Wall', 'WallBeamDesignData', 'WallColumnDesignData', 'WallHole', 'WallSection', 'WindwKind', 'WindwSection', 'WindwShape']
class Bardata:
    def GetSectProperty_beam(self, arg0: BeamSection, arg1: MaterialData) -> PySectionProperty:
        ...
    def GetSectProperty_brace(self, arg0: BraceSection, arg1: MaterialData) -> PySectionProperty:
        ...
    def GetSectProperty_column(self, arg0: ColumnSection, arg1: MaterialData) -> PySectionProperty:
        ...
    def __init__(self) -> None:
        ...
class Beam:
    def GetConcreteGrade(self) -> float:
        ...
    def GetID(self) -> int:
        ...
    def GetLoad(self) -> tuple[int, list[int], list[int]]:
        ...
    def GetSect(self) -> int:
        ...
    def GetSeg(self) -> tuple[int, int, int, int, int, float]:
        ...
    def GetSeisGrade(self) -> int:
        ...
    @typing.overload
    def GetSpecial(self) -> list[float]:
        ...
    @typing.overload
    def GetSpecial(self, arg0: SpecialBeam) -> float:
        ...
    def GetSteelGrade(self) -> float:
        ...
    def SetConcreteGrade(self, arg0: float) -> None:
        ...
    def SetLoad(self, arg0: int, arg1: list[int], arg2: list[int]) -> None:
        ...
    def SetSect(self, arg0: int) -> None:
        ...
    def SetSeg(self, arg0: int, arg1: int, arg2: int, arg3: int, arg4: float) -> None:
        ...
    def SetSeisGrade(self, arg0: int) -> None:
        ...
    @typing.overload
    def SetSpecial(self, arg0: SpecialBeam, arg1: float) -> None:
        ...
    @typing.overload
    def SetSpecial(self, arg0: list[float]) -> None:
        ...
    def SetSteelGrade(self, arg0: float) -> None:
        ...
    def __init__(self) -> None:
        ...
class BeamDesignData:
    def GetAxialCompression(self) -> list[float]:
        ...
    def GetAxialTension(self) -> list[float]:
        ...
    def GetCalcMax1(self) -> list[float]:
        ...
    def GetCalcMax2(self) -> list[float]:
        ...
    def GetCalcMax3(self) -> list[float]:
        ...
    def GetCalcMax4(self) -> list[float]:
        ...
    def GetConcreteGrade(self) -> float:
        ...
    def GetConcreteQuantity(self) -> float:
        ...
    def GetDownReinforce(self) -> list[float]:
        ...
    def GetExceedLimitInfo(self) -> list[ExceedLimitInfomation]:
        ...
    def GetFloorNo(self) -> int:
        ...
    def GetForce(self) -> dict[str, dict[int, list[float]]]:
        ...
    def GetHeightThickRatio(self) -> list[float]:
        ...
    def GetMaxShearCompressionRatio(self) -> float:
        ...
    def GetNegaMoment(self) -> list[float]:
        ...
    def GetNegaMomentLoadCase(self) -> list[int]:
        ...
    def GetNegativeMomentReinforceRatio(self) -> list[float]:
        ...
    def GetPmid(self) -> int:
        ...
    def GetPosiMoment(self) -> list[float]:
        ...
    def GetPosiMomentloadCase(self) -> list[int]:
        ...
    def GetPositiveMomentReinforceRatio(self) -> list[float]:
        ...
    def GetReinForceQuantity(self) -> float:
        ...
    def GetReinforceArea(self) -> float:
        ...
    def GetRolledSteelQuantity(self) -> float:
        ...
    def GetShearCompressionRatio(self) -> float:
        ...
    def GetShearForce(self) -> list[float]:
        ...
    def GetShearingforce(self) -> float:
        ...
    def GetSingleStirrupArea(self) -> float:
        ...
    def GetSlenderRatio(self) -> list[float]:
        ...
    def GetSteelGrade(self) -> float:
        ...
    def GetSteelQuantity(self) -> float:
        ...
    def GetStirrupArea(self) -> float:
        ...
    def GetStirrupInNonDenseArea(self) -> float:
        ...
    def GetTopReinforce(self) -> list[float]:
        ...
    def GetTorsion(self) -> float:
        ...
    def GetTowerNo(self) -> int:
        ...
    def GetWeldSteelQuantity(self) -> float:
        ...
    def GetWidthThickRatio(self) -> list[float]:
        ...
    def __init__(self) -> None:
        ...
class BeamSection:
    def GetID(self) -> int:
        ...
    def GetStandSteelSect(self) -> tuple[str, SectionShape]:
        ...
    def GetUserSect(self) -> tuple[SectionKind, SectionShape]:
        ...
    def SetStandSteelSect(self, arg0: str, arg1: SectionShape) -> None:
        ...
    def SetUserSect(self, arg0: SectionKind, arg1: SectionShape) -> None:
        ...
    def __init__(self) -> None:
        ...
class BearingShear:
    def GetFloorNum(self) -> int:
        ...
    def GetLimitVal(self) -> float:
        ...
    def GetRatx(self) -> float:
        ...
    def GetRaty(self) -> float:
        ...
    def GetTowerNum(self) -> int:
        ...
    def __init__(self) -> None:
        ...
class Brace:
    def GetConcreteGrade(self) -> float:
        ...
    def GetID(self) -> int:
        ...
    def GetSect(self) -> int:
        ...
    def GetSeg(self) -> tuple[int, int, int, int, int, int, int, float, int, int]:
        """
        isect, startOffsetX, startOffsetY, startEle, endOffsetX, endOffsetY, endEle, rotateAng, wholeEx, wholeEy
        """
    def GetSegEx(self) -> tuple[int, int, int, int, int, int, int, int, int, float, int, int]:
        """
        isect, startNodeID, endNodeID, startOffsetX, startOffsetY, startEle, endOffsetX, endOffsetY, endEle, rotateAng, wholeEx, wholeEy
        """
    def GetSeisGrade(self) -> int:
        ...
    @typing.overload
    def GetSpecial(self) -> list[float]:
        ...
    @typing.overload
    def GetSpecial(self, arg0: SpecialBrace) -> float:
        ...
    def GetSteelGrade(self) -> float:
        ...
    def SetConcreteGrade(self, arg0: float) -> None:
        ...
    def SetSect(self, arg0: int) -> None:
        ...
    def SetSeg(self, isect: int, startEle: int, endEle: int, rotateAng: float) -> None:
        ...
    def SetSegEx(self, isect: int, startOffsetX: int, startOffsetY: int, startEle: int, endOffsetX: int, endOffsetY: int, endEle: int, rotateAng: float, wholeEx: int, wholeEy: int) -> None:
        ...
    @typing.overload
    def SetSeisGrade(self, arg0: int) -> None:
        ...
    @typing.overload
    def SetSeisGrade(self, arg0: int) -> None:
        ...
    @typing.overload
    def SetSpecial(self, arg0: SpecialBrace, arg1: float) -> None:
        ...
    @typing.overload
    def SetSpecial(self, arg0: list[float]) -> None:
        ...
    def SetSteelGrade(self, arg0: float) -> None:
        ...
    def __init__(self) -> None:
        ...
class BraceDesignData:
    def GetAntiSeismClass(self) -> int:
        ...
    def GetAxialCompresRatio(self) -> list[float]:
        ...
    def GetCalcMax1(self) -> list[float]:
        ...
    def GetCalcMax2(self) -> list[float]:
        ...
    def GetCalcMax3(self) -> list[float]:
        ...
    def GetColumnAreaRatio(self) -> float:
        ...
    def GetConcreteGrade(self) -> float:
        ...
    def GetConcreteQuantity(self) -> float:
        ...
    def GetElementid(self) -> int:
        ...
    def GetExceedLimitInfo(self) -> list[ExceedLimitInfomation]:
        ...
    def GetFloorNo(self) -> int:
        ...
    def GetForce(self) -> dict[str, dict[int, list[float]]]:
        ...
    def GetHeightThickRatio(self) -> list[float]:
        ...
    def GetJoint_1(self) -> int:
        ...
    def GetJoint_2(self) -> int:
        ...
    def GetOneAngleReinArea(self) -> float:
        ...
    def GetPmid(self) -> int:
        ...
    def GetReinForceQuantity(self) -> float:
        ...
    def GetRolledSteelQuantity(self) -> float:
        ...
    def GetSlenderRatio(self) -> list[float]:
        ...
    def GetSteelGrade(self) -> float:
        ...
    def GetSteelQuantity(self) -> float:
        ...
    def GetTowerNo(self) -> int:
        ...
    def GetWeldSteelQuantity(self) -> float:
        ...
    def GetWidthThickRatio(self) -> list[float]:
        ...
    def GetXReinArea(self) -> float:
        ...
    def GetXShearCompresRatio(self) -> list[float]:
        ...
    def GetYReinArea(self) -> float:
        ...
    def GetYShearCompresRatio(self) -> list[float]:
        ...
    def __init__(self) -> None:
        ...
class BraceSection:
    def GetID(self) -> int:
        ...
    def GetStandSteelSect(self) -> tuple[str, SectionShape]:
        ...
    def GetUserSect(self) -> tuple[SectionKind, SectionShape]:
        ...
    def SetStandSteelSect(self, arg0: str, arg1: SectionShape) -> None:
        ...
    def SetUserSect(self, arg0: SectionKind, arg1: SectionShape) -> None:
        ...
    def __init__(self) -> None:
        ...
class Column:
    def GetConcreteGrade(self) -> float:
        ...
    def GetID(self) -> int:
        ...
    def GetLoad(self) -> tuple[int, list[int], list[int]]:
        ...
    def GetSect(self) -> int:
        ...
    def GetSeg(self) -> tuple[int, int, int, int, int, float]:
        ...
    def GetSeisGrade(self) -> int:
        ...
    @typing.overload
    def GetSpecial(self) -> list[float]:
        ...
    @typing.overload
    def GetSpecial(self, arg0: SpecialColumn) -> float:
        ...
    def GetSteelGrade(self) -> float:
        ...
    def SetConcreteGrade(self, arg0: float) -> None:
        ...
    def SetLoad(self, arg0: int, arg1: list[int], arg2: list[int]) -> None:
        ...
    def SetSect(self, arg0: int) -> None:
        ...
    def SetSeg(self, arg0: int, arg1: int, arg2: int, arg3: int, arg4: float) -> None:
        ...
    def SetSeisGrade(self, arg0: int) -> None:
        ...
    @typing.overload
    def SetSpecial(self, arg0: SpecialColumn, arg1: float) -> None:
        ...
    @typing.overload
    def SetSpecial(self, arg0: list[float]) -> None:
        ...
    def SetSteelGrade(self, arg0: float) -> None:
        ...
    def __init__(self) -> None:
        ...
class ColumnDesignData:
    def GetAntiSeismClass(self) -> int:
        ...
    def GetAxialCompresRatio(self) -> list[float]:
        ...
    def GetCalcMax1(self) -> list[float]:
        ...
    def GetCalcMax2(self) -> list[float]:
        ...
    def GetCalcMax3(self) -> list[float]:
        ...
    def GetColumnAreaRatio(self) -> float:
        ...
    def GetColumnSpanRatio(self) -> float:
        ...
    def GetConcreteGrade(self) -> float:
        ...
    def GetConcreteQuantity(self) -> float:
        ...
    def GetElementid(self) -> int:
        ...
    def GetEnvelopeInternalForces(self) -> dict[int, list[tuple[int, float]]]:
        ...
    def GetExceedLimitInfo(self) -> list[ExceedLimitInfomation]:
        ...
    def GetFloorNo(self) -> int:
        ...
    def GetForce(self) -> dict[str, dict[int, list[float]]]:
        ...
    def GetHeightThickRatio(self) -> list[float]:
        ...
    def GetHoopReinGrade(self) -> float:
        ...
    def GetJoint_1(self) -> int:
        ...
    def GetJoint_2(self) -> int:
        ...
    def GetMainReinGrade(self) -> float:
        ...
    def GetOneAngleReinArea(self) -> float:
        ...
    def GetPmid(self) -> int:
        ...
    def GetReinForceQuantity(self) -> float:
        ...
    def GetRolledSteelQuantity(self) -> float:
        ...
    def GetSlenderRatio(self) -> list[float]:
        ...
    def GetSteelGrade(self) -> float:
        ...
    def GetSteelQuantity(self) -> float:
        ...
    def GetTowerNo(self) -> int:
        ...
    def GetVolumnHoopRatio(self) -> float:
        ...
    def GetWeldSteelQuantity(self) -> float:
        ...
    def GetWidthThickRatio(self) -> list[float]:
        ...
    def GetXReinArea(self) -> float:
        ...
    def GetXShearCompresRatio(self) -> list[float]:
        ...
    def GetYReinArea(self) -> float:
        ...
    def GetYShearCompresRatio(self) -> list[float]:
        ...
    def __init__(self) -> None:
        ...
class ColumnSection:
    def GetID(self) -> int:
        ...
    def GetStandSteelSect(self) -> tuple[str, SectionShape]:
        ...
    def GetUserSect(self) -> tuple[SectionKind, SectionShape]:
        ...
    def SetStandSteelSect(self, arg0: str, arg1: SectionShape) -> None:
        ...
    def SetUserSect(self, arg0: SectionKind, arg1: SectionShape) -> None:
        ...
    def __init__(self) -> None:
        ...
class ConcreteGrade:
    """
    Members:
    
      C15
    
      C20
    
      C25
    
      C30
    
      C35
    
      C40
    
      C45
    
      C50
    
      C55
    
      C60
    
      C65
    
      C70
    
      C75
    
      C80
    
      C85
    
      C90
    
      C95
    
      C100
    
      None
    """
    C100: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C100: 100>
    C15: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C15: 15>
    C20: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C20: 20>
    C25: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C25: 25>
    C30: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C30: 30>
    C35: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C35: 35>
    C40: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C40: 40>
    C45: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C45: 45>
    C50: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C50: 50>
    C55: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C55: 55>
    C60: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C60: 60>
    C65: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C65: 65>
    C70: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C70: 70>
    C75: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C75: 75>
    C80: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C80: 80>
    C85: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C85: 85>
    C90: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C90: 90>
    C95: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.C95: 95>
    None: typing.ClassVar[ConcreteGrade]  # value = <ConcreteGrade.None: 0>
    __members__: typing.ClassVar[dict[str, ConcreteGrade]]  # value = {'C15': <ConcreteGrade.C15: 15>, 'C20': <ConcreteGrade.C20: 20>, 'C25': <ConcreteGrade.C25: 25>, 'C30': <ConcreteGrade.C30: 30>, 'C35': <ConcreteGrade.C35: 35>, 'C40': <ConcreteGrade.C40: 40>, 'C45': <ConcreteGrade.C45: 45>, 'C50': <ConcreteGrade.C50: 50>, 'C55': <ConcreteGrade.C55: 55>, 'C60': <ConcreteGrade.C60: 60>, 'C65': <ConcreteGrade.C65: 65>, 'C70': <ConcreteGrade.C70: 70>, 'C75': <ConcreteGrade.C75: 75>, 'C80': <ConcreteGrade.C80: 80>, 'C85': <ConcreteGrade.C85: 85>, 'C90': <ConcreteGrade.C90: 90>, 'C95': <ConcreteGrade.C95: 95>, 'C100': <ConcreteGrade.C100: 100>, 'None': <ConcreteGrade.None: 0>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: int) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: int) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class EarthquakeNormStatData:
    def GetRSG_T(self) -> float:
        ...
    def Getifloor(self) -> int:
        ...
    def Getiloadcase(self) -> int:
        ...
    def Getitower(self) -> int:
        ...
    def __init__(self) -> None:
        ...
class ExceedLimitInfomation:
    def __init__(self) -> None:
        ...
    @property
    def m_ExceedStr(self) -> str:
        ...
    @property
    def m_ExceedType(self) -> int:
        ...
class LoadCaseData:
    def GetKind(self) -> int:
        ...
    def GetName(self) -> str:
        ...
    def GetType(self) -> int:
        ...
    def Set(self, arg0: str, arg1: int, arg2: int) -> None:
        ...
    def __init__(self) -> None:
        ...
class LoadDefineData:
    def Get(self) -> tuple[int, list[float]]:
        ...
    def GetID(self) -> int:
        ...
    def Set(self, arg0: int, arg1: list[float]) -> None:
        ...
    def __init__(self) -> None:
        ...
class MaterialData:
    def __init__(self) -> None:
        ...
    def getEc(self) -> None:
        ...
class ModePeriodData:
    def GetAngle(self) -> float:
        ...
    def GetCycle(self) -> float:
        ...
    def GetDampingRatio(self) -> float:
        ...
    def GetIndex(self) -> int:
        ...
    def GetTorsi(self) -> float:
        ...
    def GetType(self) -> int:
        ...
    def GetxSide(self) -> float:
        ...
    def GetySide(self) -> float:
        ...
    def __init__(self) -> None:
        ...
class Model:
    def AddBeamSection(self, arg0: BeamSection) -> int:
        ...
    def AddBraceSection(self, arg0: BraceSection) -> int:
        ...
    def AddColumnSection(self, arg0: ColumnSection) -> int:
        ...
    def AddLoadDefine(self, arg0: LoadDefineData) -> int:
        ...
    def AddNaturalFloor(self, arg0: RealFloor) -> None:
        ...
    def AddPlaoSection(self, arg0: PlaoSection) -> int:
        ...
    @typing.overload
    def AddSlabHoleSection(self, arg0: SlabHoleSection) -> int:
        ...
    @typing.overload
    def AddSlabHoleSection(self, arg0: SlabHoleSection) -> int:
        ...
    @typing.overload
    def AddStandFloor(self) -> int:
        ...
    @typing.overload
    def AddStandFloor(self, nSrcFlr: int) -> int:
        ...
    def AddUserLoadCase(self, arg0: LoadCaseData) -> int:
        ...
    def AddWallSection(self, arg0: WallSection) -> int:
        ...
    def AddWindwSection(self, arg0: WindwSection) -> int:
        ...
    def CreatNewModel(self, arg0: str, arg1: str) -> None:
        ...
    def DelPlateLoad(self, arg0: int) -> None:
        ...
    def DelUserLoadCase(self, arg0: int) -> None:
        ...
    def DeleteStandFloor(self, arg0: int) -> int:
        ...
    def GetAllDesignPara(self) -> list[float]:
        ...
    def GetBeamSectCount(self) -> int:
        ...
    def GetBeamSection(self, arg0: int) -> BeamSection:
        ...
    def GetBraceSectCount(self) -> int:
        ...
    def GetBraceSection(self, arg0: int) -> BraceSection:
        ...
    def GetColumnSectCount(self) -> int:
        ...
    def GetColumnSection(self, arg0: int) -> ColumnSection:
        ...
    def GetCurrentStandFloor(self) -> StandFloor:
        ...
    def GetCurrentStandFloorNo(self) -> int:
        ...
    def GetFloorAssemTable(self, arg0: int) -> RealFloor:
        ...
    def GetFullJwsPath(self) -> str:
        ...
    def GetLoadDefine(self, arg0: int) -> LoadDefineData:
        ...
    def GetLoadDefineCount(self) -> int:
        ...
    def GetNatualFloorCount(self) -> int:
        ...
    def GetOneDesignParaValue(self, arg0: int) -> float:
        ...
    def GetPlaoSectCount(self) -> int:
        ...
    def GetPlaoSection(self, arg0: int) -> PlaoSection:
        ...
    def GetProjectPara(self) -> ProjectPara:
        ...
    def GetSlabHoleSectCount(self) -> int:
        ...
    def GetSlabHoleSection(self, arg0: int) -> SlabHoleSection:
        ...
    def GetStandFloorCount(self) -> int:
        ...
    def GetUserLoadCase(self, arg0: int) -> LoadCaseData:
        ...
    def GetUserLoadCaseCount(self) -> int:
        ...
    def GetUserLoadCaseIDList(self) -> list[int]:
        ...
    def GetWallSectCount(self) -> int:
        ...
    def GetWallSection(self, arg0: int) -> WallSection:
        ...
    def GetWindwSection(self, arg0: int) -> WindwSection:
        ...
    def GetWindwSectionCount(self) -> int:
        ...
    def InitialMainBuildingMem(self) -> None:
        ...
    def ModifyBeamSection(self, arg0: int, arg1: BeamSection) -> None:
        ...
    def ModifyBraceSection(self, arg0: int, arg1: BraceSection) -> None:
        ...
    def ModifyColumnSection(self, arg0: int, arg1: ColumnSection) -> None:
        ...
    def ModifyLoadDefine(self, arg0: int, arg1: LoadDefineData) -> None:
        ...
    def ModifyPlaoSection(self, arg0: int, arg1: PlaoSection) -> None:
        ...
    def ModifySlabHoleSection(self, arg0: int, arg1: SlabHoleSection) -> None:
        ...
    def ModifyUserLoadCase(self, arg0: int, arg1: LoadCaseData) -> None:
        ...
    def ModifyWallSection(self, arg0: int, arg1: WallSection) -> None:
        ...
    def ModifyWindwSection(self, arg0: int, arg1: WindwSection) -> None:
        ...
    def OpenPMModel(self, arg0: str) -> int:
        ...
    def SaveOneStandFloor(self, arg0: int) -> None:
        ...
    def SavePMModel(self) -> None:
        ...
    def SaveProjectPara(self) -> None:
        ...
    def SetAllDesignPara(self, arg0: list[float]) -> None:
        ...
    def SetCurrentStandFloor(self, arg0: int) -> None:
        ...
    def SetFloorAssemTable(self, arg0: int, arg1: RealFloor) -> None:
        ...
    def SetNaturalFloorCount(self, arg0: int) -> None:
        ...
    def SetOneDesignParaValue(self, arg0: int, arg1: float) -> None:
        ...
    def SetStandFloorCount(self, arg0: int) -> None:
        ...
    def SyncMainBuildingMem(self) -> None:
        ...
    def __init__(self) -> None:
        ...
class Net:
    def GetArc(self) -> tuple[int, int, int]:
        ...
    def GetArcCoor(self) -> tuple[float, float, float, float, float, float, float, float, float]:
        ...
    def GetAxisID(self) -> int:
        ...
    def GetID(self) -> int:
        ...
    def GetLine(self) -> tuple[int, int]:
        ...
    def GetLineCoor(self) -> tuple[float, float, float, float]:
        ...
    def IsArc(self) -> int:
        ...
    def __init__(self) -> None:
        ...
class Node:
    def Get(self) -> tuple[float, float]:
        ...
    def GetElevation(self) -> int:
        ...
    def GetID(self) -> int:
        ...
    def GetLoad(self) -> tuple[list[int], list[int]]:
        ...
    def Set(self, arg0: float, arg1: float) -> None:
        ...
    def SetElevation(self, arg0: int) -> None:
        ...
    def SetLoad(self, arg0: list[int], arg1: list[int]) -> None:
        ...
    def __init__(self) -> None:
        ...
class NodeDisp:
    def GetDispX(self) -> float:
        ...
    def GetDispY(self) -> float:
        ...
    def GetDispZ(self) -> float:
        ...
    def __init__(self) -> None:
        ...
class NodeInResult:
    def GetCoordinateX(self) -> float:
        ...
    def GetCoordinateY(self) -> float:
        ...
    def GetCoordinateZ(self) -> float:
        ...
    def GetFloorNo(self) -> int:
        ...
    def GetNodeDisp(self) -> dict[str, NodeDisp]:
        ...
    def GetPmID(self) -> int:
        ...
    def GetTowerNo(self) -> int:
        ...
    def __init__(self) -> None:
        ...
class NormalDispStatData:
    def GetaveD(self) -> float:
        ...
    def GetiInterHarmMaxD(self) -> int:
        ...
    def GetiInterHarmMinD(self) -> int:
        ...
    def GetiInterMaxD(self) -> int:
        ...
    def GetiInterMinD(self) -> int:
        ...
    def GetiMaxD(self) -> int:
        ...
    def GetiMinD(self) -> int:
        ...
    def Getifloor(self) -> int:
        ...
    def Getiloadcase(self) -> int:
        ...
    def GetinterAveA(self) -> float:
        ...
    def GetinterHarmAveA(self) -> float:
        ...
    def GetinterHarmMaxA(self) -> float:
        ...
    def GetinterHarmMinA(self) -> float:
        ...
    def GetinterMaxA(self) -> float:
        ...
    def GetinterMinA(self) -> float:
        ...
    @typing.overload
    def GetinterRatioD(self) -> float:
        ...
    @typing.overload
    def GetinterRatioD(self) -> float:
        ...
    def GetinterTopA(self) -> float:
        ...
    def Getitower(self) -> int:
        ...
    def GetmaxD(self) -> float:
        ...
    def GetminD(self) -> float:
        ...
    def GetratioA(self) -> float:
        ...
    def GetratioD(self) -> float:
        ...
    def GettowerHarmMaxA(self) -> float:
        ...
    def __init__(self) -> None:
        ...
class Plao:
    def GetID(self) -> int:
        ...
    def GetSect(self) -> int:
        ...
    def SetSect(self, arg0: int) -> None:
        ...
    def __init__(self) -> None:
        ...
class PlaoSection:
    def Get(self) -> tuple[int, int, int, int, int, int, int, int, int]:
        ...
    def Set(self, arg0: int, arg1: int, arg2: int, arg3: int, arg4: int, arg5: int, arg6: int, arg7: int, arg8: int) -> None:
        ...
    def __init__(self) -> None:
        ...
class PlateLoadData:
    def GetAng(self) -> int:
        ...
    def GetDx(self) -> int:
        ...
    def GetDy(self) -> int:
        ...
    def GetJDid(self) -> int:
        ...
    def GetLen(self) -> int:
        ...
    def GetLodID(self) -> int:
        ...
    def GetType(self) -> int:
        ...
    def GetXAng(self) -> int:
        ...
    def SetPlateLoadData(self, arg0: int, arg1: int, arg2: float, arg3: float, arg4: float, arg5: float, arg6: float, arg7: int) -> None:
        ...
    def __init__(self) -> None:
        ...
class ProjectPara:
    def GetPara_Double(self, arg0: int) -> float:
        ...
    def GetPara_Int(self, arg0: int) -> int:
        ...
    def GetPara_String(self, arg0: int) -> str:
        ...
    def SaveSetpare(self) -> None:
        ...
    def SetParaDouble(self, arg0: int, arg1: float) -> None:
        ...
    def SetParaInt(self, arg0: int, arg1: int) -> None:
        ...
    def SetPara_String(self, arg0: int, arg1: str) -> None:
        ...
    def __init__(self) -> None:
        ...
class PySectionProperty:
    def GetArea(self) -> float:
        ...
    def GetAreaConcrete(self) -> float:
        ...
    def GetAreaSteel(self) -> float:
        ...
    def GetArf(self) -> float:
        ...
    def GetRjx(self) -> float:
        ...
    def GetRjy(self) -> float:
        ...
    def GetRjz(self) -> float:
        ...
    def GetXc(self) -> float:
        ...
    def GetYc(self) -> float:
        ...
    def __init__(self) -> None:
        ...
class RealFloor:
    def GetBottomElevation(self) -> float:
        ...
    def GetFloorHeight(self) -> float:
        ...
    def GetStandFloorIndex(self) -> int:
        ...
    def SetBottomElevation(self, arg0: float) -> None:
        ...
    def SetFloorHeight(self, arg0: float) -> None:
        ...
    def SetStandFloorIndex(self, arg0: int) -> None:
        ...
    def __init__(self) -> None:
        ...
class ReinforcingbarGrade:
    """
    Members:
    
      HPB235
    
      HPB300
    
      HPB335
    
      HPB400
    
      RRB400
    
      HRB500
    
      CRB550
    
      CRB600H
    
      HTRB600
    
      HTRB630
    """
    CRB550: typing.ClassVar[ReinforcingbarGrade]  # value = <ReinforcingbarGrade.CRB550: 7>
    CRB600H: typing.ClassVar[ReinforcingbarGrade]  # value = <ReinforcingbarGrade.CRB600H: 8>
    HPB235: typing.ClassVar[ReinforcingbarGrade]  # value = <ReinforcingbarGrade.HPB235: 1>
    HPB300: typing.ClassVar[ReinforcingbarGrade]  # value = <ReinforcingbarGrade.HPB300: 5>
    HPB335: typing.ClassVar[ReinforcingbarGrade]  # value = <ReinforcingbarGrade.HPB335: 2>
    HPB400: typing.ClassVar[ReinforcingbarGrade]  # value = <ReinforcingbarGrade.HPB400: 3>
    HRB500: typing.ClassVar[ReinforcingbarGrade]  # value = <ReinforcingbarGrade.HRB500: 6>
    HTRB600: typing.ClassVar[ReinforcingbarGrade]  # value = <ReinforcingbarGrade.HTRB600: 9>
    HTRB630: typing.ClassVar[ReinforcingbarGrade]  # value = <ReinforcingbarGrade.HTRB630: 10>
    RRB400: typing.ClassVar[ReinforcingbarGrade]  # value = <ReinforcingbarGrade.RRB400: 4>
    __members__: typing.ClassVar[dict[str, ReinforcingbarGrade]]  # value = {'HPB235': <ReinforcingbarGrade.HPB235: 1>, 'HPB300': <ReinforcingbarGrade.HPB300: 5>, 'HPB335': <ReinforcingbarGrade.HPB335: 2>, 'HPB400': <ReinforcingbarGrade.HPB400: 3>, 'RRB400': <ReinforcingbarGrade.RRB400: 4>, 'HRB500': <ReinforcingbarGrade.HRB500: 6>, 'CRB550': <ReinforcingbarGrade.CRB550: 7>, 'CRB600H': <ReinforcingbarGrade.CRB600H: 8>, 'HTRB600': <ReinforcingbarGrade.HTRB600: 9>, 'HTRB630': <ReinforcingbarGrade.HTRB630: 10>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: int) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: int) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class ResultData:
    def ClearResult(self) -> None:
        ...
    def GetAllChineseLoadCaseName(self) -> dict[str, str]:
        ...
    def GetAllLoadCaseName(self) -> dict[int, str]:
        ...
    def GetAngStoryDriftConsVal(self) -> float:
        ...
    def GetBearingShear(self) -> list[BearingShear]:
        ...
    def GetBearingShearConsVal(self) -> float:
        ...
    def GetCycleRatiooConsVal(self) -> float:
        ...
    def GetDesignBeams(self, arg0: int) -> list[BeamDesignData]:
        ...
    def GetDesignBeamsViaPmid(self, arg0: int) -> list[BeamDesignData]:
        ...
    def GetDesignBraces(self, arg0: int) -> list[BraceDesignData]:
        ...
    def GetDesignBracesViaPmid(self, arg0: int) -> list[BraceDesignData]:
        ...
    def GetDesignColumns(self, arg0: int) -> list[ColumnDesignData]:
        ...
    def GetDesignColumnsViaPmid(self, arg0: int) -> list[ColumnDesignData]:
        ...
    def GetDesignWallBeams(self, arg0: int) -> list[WallBeamDesignData]:
        ...
    def GetDesignWallBeamsViaPmid(self, arg0: int) -> list[WallBeamDesignData]:
        ...
    def GetDesignWallColumns(self, arg0: int) -> list[WallColumnDesignData]:
        ...
    def GetDesignWallColumnsViaPmid(self, arg0: int) -> list[WallColumnDesignData]:
        ...
    def GetDispRatio(self) -> dict[str, list[NormalDispStatData]]:
        ...
    def GetEarthquakeNormStats(self) -> list[EarthquakeNormStatData]:
        ...
    def GetFloorinex(self) -> int:
        ...
    def GetModePeriods(self) -> list[ModePeriodData]:
        ...
    def GetNormalDispStats_Earthquake(self) -> list[NormalDispStatData]:
        ...
    def GetNormalDispStats_Static(self) -> list[NormalDispStatData]:
        ...
    def GetPyNodeInResult(self) -> list[NodeInResult]:
        ...
    def GetRatShearWeightConsVal(self) -> float:
        ...
    def GetRigidWeightRatioConsVal(self) -> float:
        ...
    def GetStiffWeightRatioFrame(self) -> list[StiffWeightRatioFrameData]:
        ...
    def GetStiffWeightRatioNonFrame(self) -> StiffWeightRatioNonFrameData:
        ...
    def GetStoreyStiffRatio(self) -> dict[int, dict[int, StoreyStiffRatioData]]:
        ...
    def GetStoreyStifs(self) -> list[StoreyStifData]:
        ...
    def GetStoreyUnitMass(self) -> list[StoreyUnitMassData]:
        ...
    def GetStoryDrift_Earthquake(self) -> dict[str, list[NormalDispStatData]]:
        ...
    def GetStoryDrift_Wind(self) -> dict[str, list[NormalDispStatData]]:
        ...
    def GetSysInfoDetail(self) -> SysInfoDetail:
        ...
    def GetTowerIndex(self) -> int:
        ...
    def InitialResult(self, arg0: str) -> int:
        ...
    def __init__(self) -> None:
        ...
class SectionKind:
    """
    Members:
    
      IDSec_Rectangle
    
      IDSec_I
    
      IDSec_Circle
    
      IDSec_ISOPolygon
    
      IDSec_Channel
    
      IDSec_FourWinged
    
      IDSec_Box
    
      IDSec_Tube
    
      IDSec_Two_Bath_Channel
    
      IDSec_Four_Winged_I
    
      IDSec_Trapezoid
    
      IDSec_Steel_Pipe_Comcrete
    
      IDSec_I_Steel_Framed_Concrete
    
      IDSec_Box_Steel_Framed_Concrete
    
      IDSec_Four_Winged_Steel_Framed_Concrete
    
      IDSec_Variable_Cross_section
    
      IDSec_VarCro_RECT
    
      IDSec_VarCro_TRAPE
    
      IDSec_VarCro_BOX
    
      IDSec_STEEL
    
      IDSec_L
    
      IDSec_T
    """
    IDSec_Box: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_Box: 7>
    IDSec_Box_Steel_Framed_Concrete: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_Box_Steel_Framed_Concrete: 14>
    IDSec_Channel: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_Channel: 5>
    IDSec_Circle: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_Circle: 3>
    IDSec_FourWinged: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_FourWinged: 6>
    IDSec_Four_Winged_I: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_Four_Winged_I: 10>
    IDSec_Four_Winged_Steel_Framed_Concrete: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_Four_Winged_Steel_Framed_Concrete: 15>
    IDSec_I: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_I: 2>
    IDSec_ISOPolygon: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_ISOPolygon: 4>
    IDSec_I_Steel_Framed_Concrete: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_I_Steel_Framed_Concrete: 13>
    IDSec_L: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_L: 28>
    IDSec_Rectangle: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_Rectangle: 1>
    IDSec_STEEL: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_STEEL: 26>
    IDSec_Steel_Pipe_Comcrete: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_Steel_Pipe_Comcrete: 12>
    IDSec_T: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_T: 29>
    IDSec_Trapezoid: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_Trapezoid: 11>
    IDSec_Tube: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_Tube: 8>
    IDSec_Two_Bath_Channel: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_Two_Bath_Channel: 9>
    IDSec_VarCro_BOX: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_VarCro_BOX: 23>
    IDSec_VarCro_RECT: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_VarCro_RECT: 21>
    IDSec_VarCro_TRAPE: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_VarCro_TRAPE: 22>
    IDSec_Variable_Cross_section: typing.ClassVar[SectionKind]  # value = <SectionKind.IDSec_Variable_Cross_section: 16>
    __members__: typing.ClassVar[dict[str, SectionKind]]  # value = {'IDSec_Rectangle': <SectionKind.IDSec_Rectangle: 1>, 'IDSec_I': <SectionKind.IDSec_I: 2>, 'IDSec_Circle': <SectionKind.IDSec_Circle: 3>, 'IDSec_ISOPolygon': <SectionKind.IDSec_ISOPolygon: 4>, 'IDSec_Channel': <SectionKind.IDSec_Channel: 5>, 'IDSec_FourWinged': <SectionKind.IDSec_FourWinged: 6>, 'IDSec_Box': <SectionKind.IDSec_Box: 7>, 'IDSec_Tube': <SectionKind.IDSec_Tube: 8>, 'IDSec_Two_Bath_Channel': <SectionKind.IDSec_Two_Bath_Channel: 9>, 'IDSec_Four_Winged_I': <SectionKind.IDSec_Four_Winged_I: 10>, 'IDSec_Trapezoid': <SectionKind.IDSec_Trapezoid: 11>, 'IDSec_Steel_Pipe_Comcrete': <SectionKind.IDSec_Steel_Pipe_Comcrete: 12>, 'IDSec_I_Steel_Framed_Concrete': <SectionKind.IDSec_I_Steel_Framed_Concrete: 13>, 'IDSec_Box_Steel_Framed_Concrete': <SectionKind.IDSec_Box_Steel_Framed_Concrete: 14>, 'IDSec_Four_Winged_Steel_Framed_Concrete': <SectionKind.IDSec_Four_Winged_Steel_Framed_Concrete: 15>, 'IDSec_Variable_Cross_section': <SectionKind.IDSec_Variable_Cross_section: 16>, 'IDSec_VarCro_RECT': <SectionKind.IDSec_VarCro_RECT: 21>, 'IDSec_VarCro_TRAPE': <SectionKind.IDSec_VarCro_TRAPE: 22>, 'IDSec_VarCro_BOX': <SectionKind.IDSec_VarCro_BOX: 23>, 'IDSec_STEEL': <SectionKind.IDSec_STEEL: 26>, 'IDSec_L': <SectionKind.IDSec_L: 28>, 'IDSec_T': <SectionKind.IDSec_T: 29>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: int) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: int) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class SectionShape:
    def Get_B(self) -> int:
        ...
    def Get_B1(self) -> int:
        ...
    def Get_B2(self) -> int:
        ...
    def Get_D(self) -> int:
        ...
    def Get_F(self) -> int:
        ...
    def Get_H(self) -> int:
        ...
    def Get_H1(self) -> int:
        ...
    def Get_H2(self) -> int:
        ...
    def Get_L(self) -> int:
        ...
    def Get_M(self) -> int:
        ...
    def Get_P(self) -> int:
        ...
    def Get_T(self) -> int:
        ...
    def Get_T1(self) -> int:
        ...
    def Get_T2(self) -> int:
        ...
    def Get_Tw(self) -> int:
        ...
    def Get_U(self) -> int:
        ...
    def Set_B(self, val: int) -> None:
        ...
    def Set_B1(self, val: int) -> None:
        ...
    def Set_B2(self, val: int) -> None:
        ...
    def Set_D(self, val: int) -> None:
        ...
    def Set_F(self, val: int) -> None:
        ...
    def Set_H(self, val: int) -> None:
        ...
    def Set_H1(self, val: int) -> None:
        ...
    def Set_H2(self, val: int) -> None:
        ...
    def Set_L(self, val: int) -> None:
        ...
    def Set_M(self, val: int) -> None:
        ...
    def Set_P(self, val: int) -> None:
        ...
    def Set_T(self, val: int) -> None:
        ...
    def Set_T1(self, val: int) -> None:
        ...
    def Set_T2(self, val: int) -> None:
        ...
    def Set_Tw(self, val: int) -> None:
        ...
    def Set_U(self, val: int) -> None:
        ...
    def __init__(self) -> None:
        ...
class Slab:
    def AddLoad(self, arg0: PlateLoadData) -> None:
        ...
    def DelLoad(self) -> None:
        ...
    def Get(self) -> tuple[int, float, float, int]:
        ...
    def GetHoles(self) -> tuple[int, list[int]]:
        ...
    def GetID(self) -> int:
        ...
    def GetLoad(self) -> list[PlateLoadData]:
        ...
    def GetNetID(self) -> list[int]:
        ...
    def GetPolygon(self) -> list[dict[float, float]]:
        ...
    def GetUniformLoad(self, arg0: int) -> float:
        ...
    def Set(self, arg0: int, arg1: float, arg2: float, arg3: int) -> None:
        ...
    def SetUniformLoad(self, arg0: int, arg1: float) -> None:
        ...
    def __init__(self) -> None:
        ...
class SlabHole:
    def GetCornerCoor(self) -> list[tuple[float, float]]:
        ...
    def GetID(self) -> int:
        ...
    def GetSect(self) -> int:
        ...
    def __init__(self) -> None:
        ...
class SlabHoleSection:
    def Get(self) -> tuple[int, int, int, int, int]:
        ...
    def Set(self, arg0: int, arg1: int, arg2: int, arg3: int, arg4: int) -> None:
        ...
    def __init__(self) -> None:
        ...
class SpecialBeam:
    """
    Members:
    
      IDSp_SeismicGrade
    
      IDSp_SeismicGrade_Structure
    
      IDSp_Constrain_Support
    
      IDSp_AmplitudeModulation
    
      IDSp_RigidCoefficient
    
      IDSp_TorqueReduction
    
      IDSp_AmplitudeModulation_Factor
    
      IDSp_Coupling_WindRigidCoefficient
    """
    IDSp_AmplitudeModulation: typing.ClassVar[SpecialBeam]  # value = <SpecialBeam.IDSp_AmplitudeModulation: 5>
    IDSp_AmplitudeModulation_Factor: typing.ClassVar[SpecialBeam]  # value = <SpecialBeam.IDSp_AmplitudeModulation_Factor: 8>
    IDSp_Constrain_Support: typing.ClassVar[SpecialBeam]  # value = <SpecialBeam.IDSp_Constrain_Support: 4>
    IDSp_Coupling_WindRigidCoefficient: typing.ClassVar[SpecialBeam]  # value = <SpecialBeam.IDSp_Coupling_WindRigidCoefficient: 9>
    IDSp_RigidCoefficient: typing.ClassVar[SpecialBeam]  # value = <SpecialBeam.IDSp_RigidCoefficient: 6>
    IDSp_SeismicGrade: typing.ClassVar[SpecialBeam]  # value = <SpecialBeam.IDSp_SeismicGrade: 2>
    IDSp_SeismicGrade_Structure: typing.ClassVar[SpecialBeam]  # value = <SpecialBeam.IDSp_SeismicGrade_Structure: 3>
    IDSp_TorqueReduction: typing.ClassVar[SpecialBeam]  # value = <SpecialBeam.IDSp_TorqueReduction: 7>
    __members__: typing.ClassVar[dict[str, SpecialBeam]]  # value = {'IDSp_SeismicGrade': <SpecialBeam.IDSp_SeismicGrade: 2>, 'IDSp_SeismicGrade_Structure': <SpecialBeam.IDSp_SeismicGrade_Structure: 3>, 'IDSp_Constrain_Support': <SpecialBeam.IDSp_Constrain_Support: 4>, 'IDSp_AmplitudeModulation': <SpecialBeam.IDSp_AmplitudeModulation: 5>, 'IDSp_RigidCoefficient': <SpecialBeam.IDSp_RigidCoefficient: 6>, 'IDSp_TorqueReduction': <SpecialBeam.IDSp_TorqueReduction: 7>, 'IDSp_AmplitudeModulation_Factor': <SpecialBeam.IDSp_AmplitudeModulation_Factor: 8>, 'IDSp_Coupling_WindRigidCoefficient': <SpecialBeam.IDSp_Coupling_WindRigidCoefficient: 9>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: int) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: int) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class SpecialBrace:
    """
    Members:
    
      IDSp_SeismicGrade
    
      IDSp_SeismicGrade_Structure
    
      IDSp_Constrain_Support
    """
    IDSp_Constrain_Support: typing.ClassVar[SpecialBrace]  # value = <SpecialBrace.IDSp_Constrain_Support: 4>
    IDSp_SeismicGrade: typing.ClassVar[SpecialBrace]  # value = <SpecialBrace.IDSp_SeismicGrade: 2>
    IDSp_SeismicGrade_Structure: typing.ClassVar[SpecialBrace]  # value = <SpecialBrace.IDSp_SeismicGrade_Structure: 3>
    __members__: typing.ClassVar[dict[str, SpecialBrace]]  # value = {'IDSp_SeismicGrade': <SpecialBrace.IDSp_SeismicGrade: 2>, 'IDSp_SeismicGrade_Structure': <SpecialBrace.IDSp_SeismicGrade_Structure: 3>, 'IDSp_Constrain_Support': <SpecialBrace.IDSp_Constrain_Support: 4>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: int) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: int) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class SpecialColumn:
    """
    Members:
    
      IDSp_SeismicGrade
    
      IDSp_SeismicGrade_Structure
    
      IDSp_Constrain_Support
    
      IDSp_Corner_Column
    
      IDSp_Transfor_Column
    
      IDSp_DoorSteel_Column
    
      IDSp_ShearCoefficient_X
    
      IDSp_ShearCoefficient_Y
    """
    IDSp_Constrain_Support: typing.ClassVar[SpecialColumn]  # value = <SpecialColumn.IDSp_Constrain_Support: 4>
    IDSp_Corner_Column: typing.ClassVar[SpecialColumn]  # value = <SpecialColumn.IDSp_Corner_Column: 5>
    IDSp_DoorSteel_Column: typing.ClassVar[SpecialColumn]  # value = <SpecialColumn.IDSp_DoorSteel_Column: 7>
    IDSp_SeismicGrade: typing.ClassVar[SpecialColumn]  # value = <SpecialColumn.IDSp_SeismicGrade: 2>
    IDSp_SeismicGrade_Structure: typing.ClassVar[SpecialColumn]  # value = <SpecialColumn.IDSp_SeismicGrade_Structure: 3>
    IDSp_ShearCoefficient_X: typing.ClassVar[SpecialColumn]  # value = <SpecialColumn.IDSp_ShearCoefficient_X: 8>
    IDSp_ShearCoefficient_Y: typing.ClassVar[SpecialColumn]  # value = <SpecialColumn.IDSp_ShearCoefficient_Y: 9>
    IDSp_Transfor_Column: typing.ClassVar[SpecialColumn]  # value = <SpecialColumn.IDSp_Transfor_Column: 6>
    __members__: typing.ClassVar[dict[str, SpecialColumn]]  # value = {'IDSp_SeismicGrade': <SpecialColumn.IDSp_SeismicGrade: 2>, 'IDSp_SeismicGrade_Structure': <SpecialColumn.IDSp_SeismicGrade_Structure: 3>, 'IDSp_Constrain_Support': <SpecialColumn.IDSp_Constrain_Support: 4>, 'IDSp_Corner_Column': <SpecialColumn.IDSp_Corner_Column: 5>, 'IDSp_Transfor_Column': <SpecialColumn.IDSp_Transfor_Column: 6>, 'IDSp_DoorSteel_Column': <SpecialColumn.IDSp_DoorSteel_Column: 7>, 'IDSp_ShearCoefficient_X': <SpecialColumn.IDSp_ShearCoefficient_X: 8>, 'IDSp_ShearCoefficient_Y': <SpecialColumn.IDSp_ShearCoefficient_Y: 9>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: int) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: int) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class SpecialWall:
    """
    Members:
    
      IDSp_SeismicGrade
    
      IDSp_SeismicGrade_Structure
    
      IDSp_VerMinReinforcementratio
    
      IDSp_CoupBeamReductionCoefficient
    
      IDSp_Coupling_WindRigidCoefficient
    
      IDSp_HorMinReinforcementratio
    """
    IDSp_CoupBeamReductionCoefficient: typing.ClassVar[SpecialWall]  # value = <SpecialWall.IDSp_CoupBeamReductionCoefficient: 6>
    IDSp_Coupling_WindRigidCoefficient: typing.ClassVar[SpecialWall]  # value = <SpecialWall.IDSp_Coupling_WindRigidCoefficient: 7>
    IDSp_HorMinReinforcementratio: typing.ClassVar[SpecialWall]  # value = <SpecialWall.IDSp_HorMinReinforcementratio: 8>
    IDSp_SeismicGrade: typing.ClassVar[SpecialWall]  # value = <SpecialWall.IDSp_SeismicGrade: 2>
    IDSp_SeismicGrade_Structure: typing.ClassVar[SpecialWall]  # value = <SpecialWall.IDSp_SeismicGrade_Structure: 3>
    IDSp_VerMinReinforcementratio: typing.ClassVar[SpecialWall]  # value = <SpecialWall.IDSp_VerMinReinforcementratio: 5>
    __members__: typing.ClassVar[dict[str, SpecialWall]]  # value = {'IDSp_SeismicGrade': <SpecialWall.IDSp_SeismicGrade: 2>, 'IDSp_SeismicGrade_Structure': <SpecialWall.IDSp_SeismicGrade_Structure: 3>, 'IDSp_VerMinReinforcementratio': <SpecialWall.IDSp_VerMinReinforcementratio: 5>, 'IDSp_CoupBeamReductionCoefficient': <SpecialWall.IDSp_CoupBeamReductionCoefficient: 6>, 'IDSp_Coupling_WindRigidCoefficient': <SpecialWall.IDSp_Coupling_WindRigidCoefficient: 7>, 'IDSp_HorMinReinforcementratio': <SpecialWall.IDSp_HorMinReinforcementratio: 8>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: int) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: int) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class StandFloor:
    def AddArcNet(self, arg0: int, arg1: int, arg2: int) -> Net:
        ...
    def AddBeam(self, isect: int, netID: int) -> Beam:
        ...
    def AddBeamEx(self, isect: int, netID: int, offset: int, startEle: int, endEle: int, rotateAng: float) -> Beam:
        ...
    def AddBrace(self, isect: int, startNodeID: int, endNodeID: int, startEle: int, endEle: int, rotateAng: float) -> Brace:
        ...
    def AddBraceEx(self, isect: int, startNodeID: int, endNodeID: int, startOffsetX: int, startOffsetY: int, startEle: int, endOffsetX: int, endOffsetY: int, endEle: int, rotateAng: float, wholeEx: int, wholeEy: int) -> Brace:
        ...
    def AddColumn(self, isect: int, nodeID: int) -> Column:
        ...
    def AddColumnEx(self, isect: int, nodeID: int, offsetX: int, offsetY: int, BtmEle: int, rotateAng: float) -> Column:
        ...
    def AddLineLoad(self, arg0: list[list[float]], arg1: list[list[float]], arg2: int, arg3: list[float]) -> list[int]:
        ...
    def AddLineNet(self, arg0: int, arg1: int) -> Net:
        ...
    def AddNode(self, arg0: float, arg1: float) -> Node:
        ...
    def AddPlao(self, arg0: int, arg1: int, arg2: int, arg3: int, arg4: int) -> Plao:
        ...
    def AddPointLoad(self, arg0: list[float], arg1: list[float], arg2: list[list[float]], arg3: int, arg4: float, arg5: float) -> list[int]:
        ...
    def AddPolyLoad(self, arg0: list[list[float]], arg1: list[list[float]], arg2: int, arg3: list[float]) -> list[int]:
        ...
    def AddSlabHole(self, arg0: int, arg1: int, arg2: int, arg3: int, arg4: int, arg5: float) -> SlabHole:
        ...
    def AddSlabHoleAnyPosition(self, arg0: list[tuple[int, list[float], list[float], int]]) -> list[SlabHole]:
        ...
    def AddWall(self, isect: int, netID: int) -> Wall:
        ...
    def AddWallEx(self, isect: int, netID: int, offset: int, btmEle: int, startEle: int, endEle: int) -> Wall:
        ...
    def AddWallHole(self, arg0: int, arg1: int, arg2: int, arg3: int) -> WallHole:
        ...
    def AddWallHoleAnyPosition(self, arg0: list[tuple[tuple[float, float], tuple[float, float], int, int]]) -> list[WallHole]:
        ...
    def ArrangNodes(self) -> None:
        ...
    def AutoFormSlab(self) -> None:
        ...
    def DeleteBeam(self, arg0: int) -> None:
        ...
    def DeleteBeamSection(self, arg0: int) -> int:
        ...
    def DeleteBrace(self, arg0: int) -> None:
        ...
    def DeleteBraceSection(self, arg0: int) -> int:
        ...
    def DeleteColumn(self, arg0: int) -> None:
        ...
    def DeleteColumnSection(self, arg0: int) -> int:
        ...
    def DeleteNet(self, arg0: int) -> None:
        ...
    def DeleteNode(self, arg0: int) -> None:
        ...
    def DeleteSlab(self, arg0: int) -> None:
        ...
    def DeleteSlabHole(self, arg0: int) -> None:
        ...
    def DeleteWall(self, arg0: int) -> None:
        ...
    def DeleteWallHole(self, arg0: int) -> None:
        ...
    def DeleteWallSection(self, arg0: int) -> int:
        ...
    def GetBeam(self, arg0: int) -> Beam:
        ...
    def GetBeams(self) -> list[Beam]:
        ...
    def GetBrace(self, arg0: int) -> Brace:
        ...
    def GetBraces(self) -> list[Brace]:
        ...
    def GetColumn(self, arg0: int) -> Column:
        ...
    def GetColumns(self) -> list[Column]:
        ...
    def GetDeadLive(self) -> tuple[float, float]:
        ...
    def GetInfo(self) -> list[float]:
        ...
    def GetInfoValue(self, arg0: int) -> float:
        ...
    def GetNet(self, arg0: int) -> Net:
        ...
    def GetNets(self) -> list[Net]:
        ...
    def GetNode(self, arg0: int) -> Node:
        ...
    def GetNodes(self) -> list[Node]:
        ...
    def GetPlaos(self) -> list[Plao]:
        ...
    def GetSlab(self, arg0: int) -> Slab:
        ...
    def GetSlabHole(self, arg0: int) -> SlabHole:
        ...
    def GetSlabHoles(self) -> list[SlabHole]:
        ...
    def GetSlabs(self) -> list[Slab]:
        ...
    def GetWall(self, arg0: int) -> Wall:
        ...
    def GetWallHole(self, arg0: int) -> WallHole:
        ...
    def GetWallHoles(self) -> list[WallHole]:
        ...
    def GetWalls(self) -> list[Wall]:
        ...
    def SetDeadLive(self, arg0: float, arg1: float) -> None:
        ...
    def SetInfo(self, arg0: list[float]) -> None:
        ...
    def SetInfoValue(self, arg0: int, arg1: float) -> None:
        ...
    def __init__(self) -> None:
        ...
class SteelGrade:
    """
    Members:
    
      Q235
    
      Q345
    
      Q355
    
      Q390
    
      Q420
    
      LQ550
    
      Q460
    
      Q500
    
      Q550
    
      Q620
    
      Q690
    
      Q235GJ
    
      Q345GJ
    
      Q390GJ
    
      Q420GJ
    
      Q460GJ
    
      None
    """
    LQ550: typing.ClassVar[SteelGrade]  # value = <SteelGrade.LQ550: 18>
    None: typing.ClassVar[SteelGrade]  # value = <SteelGrade.None: 0>
    Q235: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q235: 3>
    Q235GJ: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q235GJ: 24>
    Q345: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q345: 16>
    Q345GJ: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q345GJ: 25>
    Q355: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q355: 355>
    Q390: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q390: 15>
    Q390GJ: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q390GJ: 26>
    Q420: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q420: 17>
    Q420GJ: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q420GJ: 27>
    Q460: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q460: 19>
    Q460GJ: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q460GJ: 28>
    Q500: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q500: 20>
    Q550: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q550: 21>
    Q620: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q620: 22>
    Q690: typing.ClassVar[SteelGrade]  # value = <SteelGrade.Q690: 23>
    __members__: typing.ClassVar[dict[str, SteelGrade]]  # value = {'Q235': <SteelGrade.Q235: 3>, 'Q345': <SteelGrade.Q345: 16>, 'Q355': <SteelGrade.Q355: 355>, 'Q390': <SteelGrade.Q390: 15>, 'Q420': <SteelGrade.Q420: 17>, 'LQ550': <SteelGrade.LQ550: 18>, 'Q460': <SteelGrade.Q460: 19>, 'Q500': <SteelGrade.Q500: 20>, 'Q550': <SteelGrade.Q550: 21>, 'Q620': <SteelGrade.Q620: 22>, 'Q690': <SteelGrade.Q690: 23>, 'Q235GJ': <SteelGrade.Q235GJ: 24>, 'Q345GJ': <SteelGrade.Q345GJ: 25>, 'Q390GJ': <SteelGrade.Q390GJ: 26>, 'Q420GJ': <SteelGrade.Q420GJ: 27>, 'Q460GJ': <SteelGrade.Q460GJ: 28>, 'None': <SteelGrade.None: 0>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: int) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: int) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class StiffWeightRatioFrameData:
    def GetHeight(self) -> float:
        ...
    def GetStiffWeightRatioX(self) -> float:
        ...
    def GetStiffWeightRatioY(self) -> float:
        ...
    def GetStiffX(self) -> float:
        ...
    def GetStiffY(self) -> float:
        ...
    def GetUpHeight(self) -> float:
        ...
    def Getifloor(self) -> int:
        ...
    def Getitower(self) -> int:
        ...
    def __init__(self) -> None:
        ...
class StiffWeightRatioNonFrameData:
    def IsCalcEarthquake(self) -> bool:
        ...
    def IsCalcWind(self) -> bool:
        ...
    def StiffWeightRatioX_EQ(self) -> float:
        ...
    def StiffWeightRatioX_Wind(self) -> float:
        ...
    def StiffWeightRatioY_EQ(self) -> float:
        ...
    def StiffWeightRatioY_Wind(self) -> float:
        ...
    def __init__(self) -> None:
        ...
class StoreyStifData:
    def GetRJX(self) -> float:
        ...
    def GetRJY(self) -> float:
        ...
    def GetRatx(self) -> float:
        ...
    def GetRaty(self) -> float:
        ...
    def GetTowerIndex(self) -> int:
        ...
    def Getfloorindex(self) -> int:
        ...
    def __init__(self) -> None:
        ...
class StoreyStiffRatioData:
    def Getifloor(self) -> int:
        ...
    def Getitower(self) -> int:
        ...
    def StiffRatio_X_70Upfloor(self) -> float:
        ...
    def StiffRatio_X_80Average3Upfloor(self) -> float:
        ...
    def StiffRatio_X_HModifyUpfloor(self) -> float:
        ...
    def StiffRatio_X_HModifyUpfloor_LimitValue(self) -> float:
        ...
    def StiffRatio_Y_70Upfloor(self) -> float:
        ...
    def StiffRatio_Y_80Average3Upfloor(self) -> float:
        ...
    def StiffRatio_Y_HModifyUpfloor(self) -> float:
        ...
    def StiffRatio_Y_HModifyUpfloor_LimitValue(self) -> float:
        ...
    def StoreyStiff_X(self) -> float:
        ...
    def StoreyStiff_Y(self) -> float:
        ...
    def __init__(self) -> None:
        ...
class StoreyUnitMassData:
    def GetArea(self) -> float:
        ...
    def GetEquiHeight(self) -> float:
        ...
    def GetEquiWidth(self) -> float:
        ...
    def GetMassRatio(self) -> float:
        ...
    def GetMaxWidth(self) -> float:
        ...
    def GetMinWidth(self) -> float:
        ...
    def GetTowerIndex(self) -> int:
        ...
    def GetUnitMass(self) -> float:
        ...
    def Getfloorindex(self) -> int:
        ...
    def GetpoidX(self) -> float:
        ...
    def GetpoidY(self) -> float:
        ...
    def __init__(self) -> None:
        ...
class SysInfoDetail:
    def GetAdjustStiffWeightRatio(self) -> float:
        ...
    def GetAgbb(self) -> float:
        ...
    def GetAgcb(self) -> float:
        ...
    def GetAgp(self) -> float:
        ...
    def GetAgw(self) -> float:
        ...
    def GetAvbb(self) -> float:
        ...
    def GetAvbmem(self) -> float:
        ...
    def GetAvcb(self) -> float:
        ...
    def GetAvw(self) -> float:
        ...
    def GetAvw_ver(self) -> float:
        ...
    def GetB_reduce_fireTruck(self) -> float:
        ...
    def GetBeamConSameWall(self) -> float:
        ...
    def GetBeam_min_acr(self) -> float:
        ...
    def GetBeam_min_atr(self) -> float:
        ...
    def GetBec_SausageDesign(self) -> float:
        ...
    def GetBec_e_disp(self) -> float:
        ...
    def GetBec_w(self) -> int:
        ...
    def GetBet(self) -> float:
        ...
    def GetBgjcpcoef(self) -> float:
        ...
    def GetBrace_angle(self) -> float:
        ...
    def GetCS_11_3_7(self) -> float:
        ...
    def GetCS_9_2_6_1(self) -> float:
        ...
    def GetCW_reduce_fireTruck(self) -> float:
        ...
    def GetCbl(self) -> float:
        ...
    def GetCgjcpcoef(self) -> float:
        ...
    def GetCoef_kj02q_max(self) -> float:
        ...
    def GetCoef_kzz02q_max(self) -> float:
        ...
    def GetCoef_weakst(self) -> float:
        ...
    def GetDamp_whole(self) -> float:
        ...
    def GetDamp_wind(self) -> float:
        ...
    def GetDamp_wind_ssd(self) -> float:
        ...
    def GetDelta_damp_ratio_max(self) -> float:
        ...
    def GetDisOutMethod(self) -> float:
        ...
    def GetDisTargetUser(self) -> float:
        ...
    def GetDs_beam(self) -> float:
        ...
    def GetDs_colu(self) -> float:
        ...
    def GetDs_wall_inner(self) -> float:
        ...
    def GetEldcoef(self) -> float:
        ...
    def GetEnlargeF(self) -> float:
        ...
    def GetFlive_coef(self) -> float:
        ...
    def GetFwind_coef(self) -> float:
        ...
    def GetGama_eh(self) -> float:
        ...
    def GetGama_g_e(self) -> float:
        ...
    def GetGama_g_swratio(self) -> float:
        ...
    def GetGama_l_swratio(self) -> float:
        ...
    def GetGysb_shear_ratio_min(self) -> float:
        ...
    def GetHighLevel(self) -> float:
        ...
    def GetI_base_load_steps(self) -> int:
        ...
    def GetI_btf_grade(self) -> int:
        ...
    def GetI_clen_coef_with_sway(self) -> int:
        ...
    def GetI_col_btf_grade(self) -> int:
        ...
    def GetI_db11_1003(self) -> int:
        ...
    def GetI_member_defect(self) -> int:
        ...
    def GetI_member_force_accu_index(self) -> int:
        ...
    def GetI_steel_code(self) -> int:
        ...
    def GetIacr_to_frame(self) -> int:
        ...
    def GetIarea(self) -> int:
        ...
    def GetIauto_base_kzdj(self) -> int:
        ...
    def GetIauto_plate_mechanics(self) -> int:
        ...
    def GetIauto_weak(self) -> int:
        ...
    def GetIautoeangle(self) -> int:
        ...
    def GetIautoregu_bcweakst(self) -> int:
        ...
    def GetIautoweakst(self) -> int:
        ...
    def GetIbeam_tiaofu(self) -> int:
        ...
    def GetIbeamdesignmom_ssbm(self) -> int:
        ...
    def GetIbimoment_ite(self) -> int:
        ...
    def GetIcal_damp_ratio(self) -> int:
        ...
    def GetIcal_resource(self) -> int:
        ...
    def GetIcalc_stifdamp_iter(self) -> int:
        ...
    def GetIclen_coefx(self) -> int:
        ...
    def GetIclen_coefy(self) -> int:
        ...
    def GetIcode_bmemsize(self) -> int:
        ...
    def GetIcol_v_frame(self) -> int:
        ...
    def GetIcombine_wind_snow(self) -> int:
        ...
    def GetIconsider_brace_for_dratio(self) -> int:
        ...
    def GetIcqc_signtype(self) -> int:
        ...
    def GetIdbef_regu(self) -> int:
        ...
    def GetIdel_overlapped_weight(self) -> int:
        ...
    def GetIdel_overlapped_weight_plate(self) -> int:
        ...
    def GetIe_cantilever_beam(self) -> int:
        ...
    def GetIe_sts(self) -> int:
        ...
    def GetIear_disp(self) -> int:
        ...
    def GetIearthfce(self) -> int:
        ...
    def GetIecc_type(self) -> int:
        ...
    def GetIefr(self) -> int:
        ...
    def GetIeh_spas(self) -> int:
        ...
    def GetIequake_base_shear(self) -> int:
        ...
    def GetIequake_xy(self) -> int:
        ...
    def GetIev_spas(self) -> int:
        ...
    def GetIew(self) -> int:
        ...
    def GetIgaodikua(self) -> int:
        ...
    def GetIgen_bw_col(self) -> int:
        ...
    def GetIgeneral_code(self) -> int:
        ...
    def GetIgrdtype(self) -> int:
        ...
    @typing.overload
    def GetIgzcxb(self) -> int:
        ...
    @typing.overload
    def GetIgzcxb(self) -> int:
        ...
    def GetIhbw_flange(self) -> int:
        ...
    def GetIoutput_condensed_stif(self) -> int:
        ...
    def GetIpfm_design(self) -> int:
        ...
    def GetIplate_design_fem(self) -> int:
        ...
    def GetIprogram_64(self) -> int:
        ...
    def GetIreduce_basell(self) -> int:
        ...
    def GetIreduce_cwll(self) -> int:
        ...
    def GetIregu_kzzb(self) -> int:
        ...
    def GetIreinv_method_wallop(self) -> int:
        ...
    def GetIreliability_code(self) -> int:
        ...
    def GetIsave_analysis_model_user_wind(self) -> int:
        ...
    def GetIsave_user_bmem(self) -> int:
        ...
    def GetIseismic_precautionary_type(self) -> int:
        ...
    def GetIset_callen_coef(self) -> int:
        ...
    def GetIshortw_consider_width(self) -> int:
        ...
    def GetIsodsn(self) -> int:
        ...
    def GetIsolver(self) -> int:
        ...
    def GetIspecial_shape_col_code(self) -> int:
        ...
    def GetIstairs(self) -> int:
        ...
    def GetIsteel_design_par(self) -> int:
        ...
    def GetIsteelbar_fyv_limit(self) -> int:
        ...
    def GetIsub_fix(self) -> int:
        ...
    def GetIswratio_fill_wall(self) -> int:
        ...
    def GetItfloor(self) -> list[int]:
        ...
    def GetItran_stif_ratio(self) -> int:
        ...
    @typing.overload
    def GetItype_bmem(self) -> int:
        ...
    @typing.overload
    def GetItype_bmem(self) -> int:
        ...
    @typing.overload
    def GetItype_bmem(self) -> int:
        ...
    def GetIunimoment(self) -> int:
        ...
    def GetIuser_define_range_index(self) -> int:
        ...
    def GetIwb_midnode(self) -> int:
        ...
    def GetIwind_considered(self) -> int:
        ...
    def GetJrigidslab(self) -> int:
        ...
    def GetK646tab(self) -> int:
        ...
    def GetK_ccode_b04(self) -> int:
        ...
    def GetKhrb500(self) -> int:
        ...
    def GetKind_tb(self) -> int:
        ...
    def GetKz_iew(self) -> int:
        ...
    def GetLiedu(self) -> int:
        ...
    def GetLive23_lev(self) -> int:
        ...
    def GetLive_load_reduction_type(self) -> int:
        ...
    def GetMethod_average_displacement_angle_index(self) -> int:
        ...
    def GetMethod_shear_span_ratio(self) -> int:
        ...
    def GetNannex(self) -> int:
        ...
    def GetNbasement0(self) -> int:
        ...
    def GetNdegree_gz(self) -> int:
        ...
    def GetNedira(self) -> int:
        ...
    def GetNegative_bar_considered(self) -> int:
        ...
    def GetNeq(self) -> int:
        ...
    def GetNor_Un_Wind(self) -> float:
        ...
    def GetNseg02q(self) -> int:
        ...
    def GetNsub(self) -> int:
        ...
    def GetNweakst(self) -> int:
        ...
    def GetPsi_temw(self) -> float:
        ...
    def GetR525_1(self) -> float:
        ...
    def GetR525_2(self) -> float:
        ...
    def GetReduce_ll1(self) -> float:
        ...
    def GetReduce_ll20up(self) -> float:
        ...
    def GetReduce_ll23(self) -> float:
        ...
    def GetReduce_ll45(self) -> float:
        ...
    def GetReduce_ll68(self) -> float:
        ...
    def GetReduce_ll920(self) -> float:
        ...
    def GetReducet(self) -> float:
        ...
    def GetRigidCol(self) -> float:
        ...
    def GetRnet(self) -> float:
        ...
    def GetRoundPipeSpecial(self) -> float:
        ...
    def GetSoil_mx(self) -> float:
        ...
    def GetSoil_my(self) -> float:
        ...
    def GetSquarePipeSpecial(self) -> float:
        ...
    def GetSteelConcreteSpecial(self) -> float:
        ...
    def GetSteel_weight_coef(self) -> float:
        ...
    def GetStru_importance(self) -> float:
        ...
    def GetStubewall_constif_coef(self) -> float:
        ...
    def GetTem_reduce(self) -> float:
        ...
    def GetTran_seis_coef(self) -> float:
        ...
    def GetTsoil_factor_x(self) -> float:
        ...
    def GetTsoil_factor_y(self) -> float:
        ...
    def GetUseColHn(self) -> float:
        ...
    def GetUtw(self) -> float:
        ...
    def GetUtwh(self) -> float:
        ...
    def GetVb_nmode(self) -> int:
        ...
    def GetVb_subspace_method(self) -> int:
        ...
    def GetVeEar(self) -> float:
        ...
    def GetWgjcpcoef(self) -> float:
        ...
    def GetWithWind(self) -> float:
        ...
    def GetYta_qdb(self) -> float:
        ...
    def GetZ_ground(self) -> float:
        ...
    def __init__(self) -> None:
        ...
class Wall:
    def GetConcreteGrade(self) -> float:
        ...
    def GetID(self) -> int:
        ...
    def GetLoad(self) -> tuple[int, list[int], list[int]]:
        ...
    def GetSect(self) -> int:
        ...
    def GetSeg(self) -> tuple[int, int, int, int, int, int]:
        ...
    def GetSeisGrade(self) -> int:
        ...
    @typing.overload
    def GetSpecial(self) -> list[float]:
        ...
    @typing.overload
    def GetSpecial(self, arg0: SpecialWall) -> float:
        ...
    def SetConcreteGrade(self, arg0: float) -> None:
        ...
    def SetLoad(self, arg0: int, arg1: list[int], arg2: list[int]) -> None:
        ...
    def SetSect(self, arg0: int) -> None:
        ...
    def SetSeg(self, arg0: int, arg1: int, arg2: int, arg3: int, arg4: int) -> None:
        ...
    def SetSeisGrade(self, arg0: int) -> None:
        ...
    @typing.overload
    def SetSpecial(self, arg0: SpecialWall, arg1: float) -> None:
        ...
    @typing.overload
    def SetSpecial(self, arg0: list[float]) -> None:
        ...
    def __init__(self) -> None:
        ...
class WallBeamDesignData:
    def GetAxialCompression(self) -> list[float]:
        ...
    def GetAxialTension(self) -> list[float]:
        ...
    def GetConcreteQuantity(self) -> float:
        ...
    def GetExceedLimitInfo(self) -> list[ExceedLimitInfomation]:
        ...
    def GetFloorNo(self) -> int:
        ...
    def GetForce(self) -> dict[str, dict[int, list[float]]]:
        ...
    def GetMaxShearCompressionRatio(self) -> float:
        ...
    def GetNegaMoment(self) -> list[float]:
        ...
    def GetNegaMomentLoadCase(self) -> list[int]:
        ...
    def GetPmid(self) -> int:
        ...
    def GetPosiMoment(self) -> list[float]:
        ...
    def GetPosiMomentloadCase(self) -> list[int]:
        ...
    def GetReinForceQuantity(self) -> float:
        ...
    def GetRolledSteelQuantity(self) -> float:
        ...
    def GetShearCompressionRatio(self) -> float:
        ...
    def GetShearForce(self) -> list[float]:
        ...
    def GetShearingforce(self) -> float:
        ...
    def GetSingleStirrupArea(self) -> float:
        ...
    def GetSteelQuantity(self) -> float:
        ...
    def GetStirrupArea(self) -> float:
        ...
    def GetStirrupInNonDenseArea(self) -> float:
        ...
    def GetTorsion(self) -> float:
        ...
    def GetTowerNo(self) -> int:
        ...
    def GetWeldSteelQuantity(self) -> float:
        ...
    def __init__(self) -> None:
        ...
class WallColumnDesignData:
    def GetAxialCompresRatio(self) -> list[float]:
        ...
    def GetConcreteQuantity(self) -> float:
        ...
    def GetElementid(self) -> int:
        ...
    def GetExceedLimitInfo(self) -> list[ExceedLimitInfomation]:
        ...
    def GetFloorNo(self) -> int:
        ...
    def GetForce(self) -> dict[str, dict[int, list[float]]]:
        ...
    def GetJoint_1(self) -> int:
        ...
    def GetJoint_2(self) -> int:
        ...
    def GetPmid(self) -> list[int]:
        ...
    def GetReinForceQuantity(self) -> float:
        ...
    def GetRolledSteelQuantity(self) -> float:
        ...
    def GetShearCompresRatio(self) -> list[float]:
        ...
    def GetSteelQuantity(self) -> float:
        ...
    def GetTowerNo(self) -> list[int]:
        ...
    def GetWallSpanRatio(self) -> list[float]:
        ...
    def GetWeldSteelQuantity(self) -> float:
        ...
    def __init__(self) -> None:
        ...
class WallHole:
    def GetID(self) -> int:
        ...
    def GetLoad(self) -> tuple[int, list[int], list[int]]:
        ...
    def GetSect(self) -> int:
        ...
    def GetSeg(self) -> tuple[int, int, int, int]:
        ...
    def SetLoad(self, arg0: int, arg1: list[int], arg2: list[int]) -> None:
        ...
    def SetSect(self, arg0: int) -> None:
        ...
    def SetSeg(self, arg0: int, arg1: int, arg2: int) -> None:
        ...
    def __init__(self) -> None:
        ...
class WallSection:
    def GetSect(self) -> tuple[int, int, int, int, int, int]:
        ...
    def SetSect(self, arg0: int, arg1: int, arg2: int, arg3: int, arg4: int, arg5: int) -> None:
        ...
    def __init__(self) -> None:
        ...
class WindwKind:
    """
    Members:
    
      IDSec_Rectangle
    """
    IDSec_Rectangle: typing.ClassVar[WindwKind]  # value = <WindwKind.IDSec_Rectangle: 1>
    __members__: typing.ClassVar[dict[str, WindwKind]]  # value = {'IDSec_Rectangle': <WindwKind.IDSec_Rectangle: 1>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: int) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: int) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class WindwSection:
    def GetWindwSect(self) -> tuple[WindwKind, WindwShape]:
        ...
    def SetWindwSect(self, arg0: WindwKind, arg1: WindwShape) -> None:
        ...
    def __init__(self) -> None:
        ...
class WindwShape:
    def Get_B(self) -> int:
        ...
    def Get_H(self) -> int:
        ...
    def Set_B(self, val: int) -> None:
        ...
    def Set_H(self, val: int) -> None:
        ...
    def __init__(self) -> None:
        ...
